.. selexe documentation master file

Welcome to selexe's documentation!
====================================

selexe is a tool to directly execute selenese files (i.e. *.sel files) created by the selenium IDE. Selenium commands
are directly translated into Python executable code without the need of manually converting selenese files into Python
code first.

This documentation applies to selexe release V |release|

Contents:

.. toctree::
   :maxdepth: 2

   intro
   installation
   manual
   license

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

